@@ -4,7 +4,7 @@
 if [ "$#" -lt 1 ]; then
     # Print usage information to standard error.
     echo "Error: No application specified." >&2
-    echo "Usage: $0 {kitty|ghostty|foot|alacritty|wezterm|fuzzel|walker|pywalfox|cava|yazi|niri|hyprland|sway|scroll|mango|btop|zathura} [dark|light]" >&2
+    echo "Usage: $0 {kitty|ghostty|foot|alacritty|wezterm|fuzzel|walker|pywalfox|cava|yazi|labwc|niri|hyprland|sway|scroll|mango|btop|zathura} [dark|light]" >&2
     exit 1
 fi
 
@@ -288,6 +288,11 @@ EOF
     fi
     ;;
 
+labwc)
+    # Update the theme
+    labwc -r
+    ;;
+
 niri)
     CONFIG_FILE="$HOME/.config/niri/config.kdl"
     INCLUDE_LINE='include "./noctalia.kdl"'
